"use client"

import { useState } from 'react'
import { motion } from 'framer-motion'
import { useRouter } from 'next/navigation'
import { Trash2, User, BookOpen } from 'lucide-react'
import { useToast } from '@/components/ui/use-toast'
import { Button } from '@/components/ui/button'
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from '@/components/ui/card'
import { Table, TableBody, TableCell, TableHead, TableHeader, TableRow } from '@/components/ui/table'

interface Teacher {
  id: string
  name: string
  subject: string
}

interface TeacherListProps {
  teachers: Teacher[]
}

export default function TeacherList({ teachers }: TeacherListProps) {
  const [isDeleting, setIsDeleting] = useState<string | null>(null)
  const router = useRouter()
  const { toast } = useToast()

  const handleDelete = async (id: string, name: string) => {
    if (confirm(`Are you sure you want to delete ${name}? This will also delete all associated slots and bookings.`)) {
      setIsDeleting(id)
      
      try {
        const res = await fetch(`/api/teachers/${id}`, {
          method: 'DELETE',
        })
        
        if (res.ok) {
          toast({
            title: 'Teacher deleted',
            description: `${name} has been removed successfully.`,
          })
          router.refresh()
        } else {
          const error = await res.json()
          throw new Error(error.error || 'Failed to delete teacher')
        }
      } catch (error) {
        console.error('Error deleting teacher:', error)
        toast({
          title: 'Failed to delete teacher',
          description: error instanceof Error ? error.message : 'An error occurred. Please try again.',
          variant: 'destructive',
        })
      } finally {
        setIsDeleting(null)
      }
    }
  }

  return (
    <motion.div
      initial={{ opacity: 0, y: 20 }}
      animate={{ opacity: 1, y: 0 }}
      transition={{ duration: 0.3, delay: 0.1 }}
    >
      <Card>
        <CardHeader>
          <CardTitle>Teachers</CardTitle>
          <CardDescription>
            Manage teachers for the parents evening booking system.
          </CardDescription>
        </CardHeader>
        <CardContent>
          {teachers.length === 0 ? (
            <div className="text-center py-6 text-muted-foreground">
              No teachers added yet. Add your first teacher using the form above.
            </div>
          ) : (
            <Table>
              <TableHeader>
                <TableRow>
                  <TableHead>Name</TableHead>
                  <TableHead>Subject</TableHead>
                  <TableHead className="text-right">Actions</TableHead>
                </TableRow>
              </TableHeader>
              <TableBody>
                {teachers.map((teacher) => (
                  <TableRow key={teacher.id}>
                    <TableCell className="font-medium flex items-center">
                      <User className="h-4 w-4 mr-2 text-primary" />
                      {teacher.name}
                    </TableCell>
                    <TableCell className="flex items-center">
                      <BookOpen className="h-4 w-4 mr-2 text-muted-foreground" />
                      {teacher.subject}
                    </TableCell>
                    <TableCell className="text-right">
                      <Button
                        variant="destructive"
                        size="sm"
                        onClick={() => handleDelete(teacher.id, teacher.name)}
                        disabled={isDeleting === teacher.id}
                      >
                        <Trash2 className="h-4 w-4 mr-2" />
                        {isDeleting === teacher.id ? 'Deleting...' : 'Delete'}
                      </Button>
                    </TableCell>
                  </TableRow>
                ))}
              </TableBody>
            </Table>
          )}
        </CardContent>
      </Card>
    </motion.div>
  )
}